API Documentation
=================

:mod:`kotti.security`
---------------------

.. autofunction:: kotti.security.set_groups
.. autofunction:: kotti.security.list_groups

.. autoclass:: kotti.security.AbstractPrincipals
    :members:

.. autoclass:: kotti.security.Principal
    :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
